@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003, 2004, 2005, 2006 Free Software Foundation
+ * Copyright (C) 2003, 2004, 2005, 2006, 2007 Free Software Foundation
  *
  * Author: Nikos Mavroyanopoulos
  *
@@ -35,33 +35,31 @@
 #include <gnutls_cert.h>
 
 /**
-  * gnutls_openpgp_privkey_init - This function initializes a gnutls_openpgp_privkey_t structure
-  * @key: The structure to be initialized
-  *
-  * This function will initialize an OpenPGP key structure. 
-  *
-  * Returns 0 on success.
-  *
-  **/
+ * gnutls_openpgp_privkey_init - This function initializes a gnutls_openpgp_privkey_t structure
+ * @key: The structure to be initialized
+ *
+ * This function will initialize an OpenPGP key structure. 
+ *
+ * Returns 0 on success.
+ *
+ **/
 int
 gnutls_openpgp_privkey_init (gnutls_openpgp_privkey_t * key)
 {
   *key = gnutls_calloc (1, sizeof (gnutls_openpgp_privkey_int));
 
   if (*key)
-    {
-      return 0;			/* success */
-    }
+    return 0; /* success */
   return GNUTLS_E_MEMORY_ERROR;
 }
 
 /**
-  * gnutls_openpgp_privkey_deinit - This function deinitializes memory used by a gnutls_openpgp_privkey_t structure
-  * @key: The structure to be initialized
-  *
-  * This function will deinitialize a key structure. 
-  *
-  **/
+ * gnutls_openpgp_privkey_deinit - This function deinitializes memory used by a gnutls_openpgp_privkey_t structure
+ * @key: The structure to be initialized
+ *
+ * This function will deinitialize a key structure. 
+ *
+ **/
 void
 gnutls_openpgp_privkey_deinit (gnutls_openpgp_privkey_t key)
 {
@@ -73,19 +71,19 @@ gnutls_openpgp_privkey_deinit (gnutls_openpgp_privkey_t key)
 }
 
 /**
-  * gnutls_openpgp_privkey_import - This function will import a RAW or BASE64 encoded key
-  * @key: The structure to store the parsed key.
-  * @data: The RAW or BASE64 encoded key.
-  * @format: One of gnutls_openpgp_key_fmt_t elements.
-  * @pass: Unused for now
-  * @flags: should be zero
-  *
-  * This function will convert the given RAW or Base64 encoded key
-  * to the native gnutls_openpgp_privkey_t format. The output will be stored in 'key'.
-  *
-  * Returns 0 on success.
-  *
-  **/
+ * gnutls_openpgp_privkey_import - This function will import a RAW or BASE64 encoded key
+ * @key: The structure to store the parsed key.
+ * @data: The RAW or BASE64 encoded key.
+ * @format: One of gnutls_openpgp_key_fmt_t elements.
+ * @pass: Unused for now
+ * @flags: should be zero
+ *
+ * This function will convert the given RAW or Base64 encoded key
+ * to the native gnutls_openpgp_privkey_t format. The output will be stored in 'key'.
+ *
+ * Returns 0 on success.
+ *
+ **/
 int
 gnutls_openpgp_privkey_import (gnutls_openpgp_privkey_t key,
 			       const gnutls_datum_t * data,
@@ -94,8 +92,7 @@ gnutls_openpgp_privkey_import (gnutls_openpgp_privkey_t key,
 {
   int rc;
 
-  rc = _gnutls_openpgp_raw_privkey_to_gkey (&key->pkey, data,
-					    format);
+  rc = _gnutls_openpgp_raw_privkey_to_gkey (&key->pkey, data, format);
   if (rc)
     {
       gnutls_assert ();
@@ -105,22 +102,23 @@ gnutls_openpgp_privkey_import (gnutls_openpgp_privkey_t key,
   return 0;
 }
 
+
 /**
-  * gnutls_openpgp_privkey_get_pk_algorithm - This function returns the key's PublicKey algorithm
-  * @key: is an OpenPGP key
-  * @bits: if bits is non null it will hold the size of the parameters' in bits
-  *
-  * This function will return the public key algorithm of an OpenPGP
-  * certificate.
-  *
-  * If bits is non null, it should have enough size to hold the parameters
-  * size in bits. For RSA the bits returned is the modulus. 
-  * For DSA the bits returned are of the public exponent.
-  *
-  * Returns a member of the GNUTLS_PKAlgorithm enumeration on success,
-  * or a negative value on error.
-  *
-  **/
+ * gnutls_openpgp_privkey_get_pk_algorithm - This function returns the key's PublicKey algorithm
+ * @key: is an OpenPGP key
+ * @bits: if bits is non null it will hold the size of the parameters' in bits
+ *
+ * This function will return the public key algorithm of an OpenPGP
+ * certificate.
+ *
+ * If bits is non null, it should have enough size to hold the parameters
+ * size in bits. For RSA the bits returned is the modulus. 
+ * For DSA the bits returned are of the public exponent.
+ *
+ * Returns a member of the GNUTLS_PKAlgorithm enumeration on success,
+ * or a negative value on error.
+ *
+ **/
 gnutls_pk_algorithm_t
 gnutls_openpgp_privkey_get_pk_algorithm (gnutls_openpgp_privkey_t key,
 					 unsigned int *bits)
@@ -135,5 +133,6 @@ gnutls_openpgp_privkey_get_pk_algorithm (gnutls_openpgp_privkey_t key,
       if (pk == GNUTLS_PK_DSA)
 	*bits = _gnutls_mpi_get_nbits (key->pkey.params[3]);
     }
+  
   return pk;
 }
